library(data.table)
library(here)
library(readxl)
library(magrittr)

dir = here()
setwd(dir)

# gen data
setwd("./raw")
gen_active = read_xlsx("3_1_Generator_Y2019.xlsx", col_names = T) %>% data.table()
gen_retire = read_xlsx("3_1_Generator_Y2019.xlsx", col_names = T, sheet = 3) %>% data.table()

  # fix headers
  col_names = gsub(" ", "_", gen_active[1,]) %>% tolower()
  names(gen_active) = col_names
  gen_active = gen_active[-1,]

  col_names = gsub(" ", "_", gen_retire[1,]) %>% tolower()
  names(gen_retire) = col_names
  gen_retire = gen_retire[-1,]
  
    # remove NA
    gen_retire = gen_retire[! is.na(retirement_year)]

# plant size
years = unique(gen_active$operating_year) %>% as.numeric() %>% sort()
gen_active$`nameplate_capacity_(mw)` = as.numeric(gen_active$`nameplate_capacity_(mw)`)
gen_retire$`nameplate_capacity_(mw)` = as.numeric(gen_retire$`nameplate_capacity_(mw)`)
mean_capacity = years

for(i in 1:length(years)){

  # year
  y = years[i]
    
  # gen_active subset that are active
  gen_active_sub = gen_active[operating_year <= y]

  # sum by plant 
  plant_active = gen_active_sub[, .(capacity = sum(`nameplate_capacity_(mw)`)), by = plant_code]
  
  # gen_retire subset that were active
  gen_retire_sub = gen_retire[operating_year <= y & retirement_year >= y]

  # sum by plant 
  plant_retire = gen_retire_sub[, .(capacity = sum(`nameplate_capacity_(mw)`)), by = plant_code]

  # merge plants
  plant_merge = rbind(plant_active, plant_retire)
  plant_merge = plant_merge[, .(capacity = sum(capacity)), by = plant_code]
  
  # mean capacity
  mean_capacity[i] = mean(plant_merge$capacity)  
  
}

# export
output = data.table(year = years, 
                    mean_capacity = mean_capacity)

setwd(dir)
fwrite(output, "plant_mean_capacity.csv")





