library(data.table)
library(here)
library(readxl)
library(magrittr)

dir = here()
setwd(dir)

# gen data
setwd("./raw")
gen_active = read_xlsx("3_1_Generator_Y2019.xlsx", col_names = T) %>% data.table()

  # fix headers
  col_names = gsub(" ", "_", gen_active[1,]) %>% tolower()
  names(gen_active) = col_names
  gen_active = gen_active[-1,]
  gen_active$`nameplate_capacity_(mw)` = as.numeric(gen_active$`nameplate_capacity_(mw)`)

  
# energy types
gen_active$type = NA

  # fossil fuel
  id = grep("Coal", gen_active$technology)
  gen_active$type[id] = "Coal"
  
  id = grep("Petroleum", gen_active$technology)
  gen_active$type[id] = "Petroleum"
  
  id = grep("Natural Gas", gen_active$technology)
  gen_active$type[id] = "Natural Gas"
  
  # nuclear
  id = grep("Nuclear", gen_active$technology)
  gen_active$type[id] = "Nuclear"
  
  # hydro
  id = grep("Hydro", gen_active$technology)
  gen_active$type[id] = "Hydro"  
  
  # solar   
  id = grep("Solar", gen_active$technology)
  gen_active$type[id] = "Solar"
  
  # wind   
  id = grep("Wind", gen_active$technology)
  gen_active$type[id] = "Wind"
  
  # biomass
  id = grep("Biomass", gen_active$technology)
  gen_active$type[id] = "Biomass"

# plant size by type  
plant = gen_active[, .(capacity = sum(`nameplate_capacity_(mw)`)), by = .(plant_code, type)] %>% na.omit()

# class 
renewable = c("Wind", "Hydro", "Solar", "Biomass")
plant$class = NA
plant$class[plant$type %in% renewable] = "Renewable"
plant$class[!plant$type %in% renewable] = "Non-renewable"

# export
setwd(dir)
fwrite(plant, "plant_capacity_by_type.csv")
