library(ineq)
library(NORMT3)
library(readr)

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
H = read.csv("Heyman.csv")

m = exp(H$Mean.Log +0.5*H$SD.Log^2)
Gini = Re(erf(H$SD.Log/2))

output = data.frame(Year = 1995, Level = H$Level, N = H$N, Mean = m, Gini, Source = "Heyman 2002")
write_csv(output, "Heyman Level Results.csv")



# between within inequality
g.outer = ineq(output$Mean)*length(output$Mean)/(length(output$Mean)-1)
g.inner = mean(output$Gini)
g.ratio = g.outer/g.inner

result = data.frame(Year = 1995, g.outer, g.inner, g.ratio, Type = "Hierarchical Level*\n(Heyman)", n.groups = 4)

write.csv(result, "Heyman Gini Ratio.csv")


# Global Inequality
payroll = NA
for(i in 1:4){
    p = rlnorm(H$N[i]*10^2, H$Mean.Log[i], H$SD.Log[i])
    payroll = c(payroll, p)
}

G = data.frame(Year = 1995, G = ineq(payroll))


write_csv(G, "Global Gini.csv")


