print("Dagum")
# code from Andrie de Vries
# https://www.r-bloggers.com/parameters-and-percentiles-the-gamma-distribution/

library(actuar)
library(ineq)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(data.table)
library(VGAM)


# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")



O = read_csv("Mueller.csv")


error <- function(p=c(1, 1, 1), quantiles, exp){
  gx <- qdagum(p=quantiles, shape1.a  = p[1], scale = p[2], shape2.p = p[3])
  sum(abs((gx-exp)))
}

quants <- c(0.25, 0.5, 0.75)
l = length(O$N)


# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)

fit =  foreach (i = 1:l, .options.snow=opts,  .combine=rbind, .packages=c('ineq',  'data.table', 'VGAM')) %dopar%  {
  
  q = as.numeric(O[i , 4:6]/1000)
  solution <- nlm(f=error, p= c(1, 1, 1), quantiles = quants, exp=q)
  
  a = solution$estimate[1]
  b = solution$estimate[2]
  p = solution$estimate[3]
 
  gini = gamma(p)*gamma(2*p +1/a)/gamma(2*p)/gamma(p +1/a) -1
  mean = - b/a*gamma(-1/a)*gamma(1/a+p)/gamma(p)
  
  test = qdagum(quants, a, b, p)
  test = t(test)


  data.table(gini, mean, test, type = "Dagum", solution$estimate[1], solution$estimate[2], solution$estimate[3], NA)
  
}
stopCluster(cl)
endTime = proc.time()
time = endTime - startTime


write_csv(fit, "Dagum Results.csv")





