print("Weibull")

# code from Andrie de Vries
# https://www.r-bloggers.com/parameters-and-percentiles-the-gamma-distribution/
library(VGAM)
library(NORMT3)
library(ineq)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(data.table)
library(actuar)


# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")



O = read_csv("Mueller.csv")


error <- function(p=c(10, 3), quantiles, exp){
  gx <- qweibull(p=quantiles, shape=p[1], scale = p[2])
  sum(abs((gx-exp)))
}


quants <- c(0.25, 0.5, 0.75)
l = length(O$N)


# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)

fit =  foreach (i = 1:l, .options.snow=opts,  .combine=rbind, .packages=c('ineq',  'data.table', 'actuar')) %dopar%  {

  q = as.numeric(O[i , 4:6]/1000)
  solution <- nlm(f=error, p= c(0.5, 0.3), quantiles = quants, exp=q)
  
  k = solution$estimate[1]
  gini = 1-2^(-1/k)
  mean = solution$estimate[2]*gamma(1 + 1/k)
  
  test = qweibull(quants, solution$estimate[1], solution$estimate[2])
  test = t(test)

  
  data.table(gini, mean, test, type = "Weibull", solution$estimate[1], solution$estimate[2], NA, NA)
  
}
stopCluster(cl)
endTime = proc.time()
time = endTime - startTime


write_csv(fit, "Weibull Results.csv")






