library(ineq)
library(readr)
library(data.table)
library(actuar)
library(VGAM)
library(magrittr)
library(truncnorm)
library(FAdist)




dir = dirname(rstudioapi::getActiveDocumentContext()$path)
workspace = gsub("Model", "Raw Data", dir)
setwd(workspace)

O = read_csv("Mueller.csv")

dir = dirname(rstudioapi::getActiveDocumentContext()$path)
workspace = paste(dir, "/Functions", sep = "")
setwd(workspace)

files = list.files(pattern = "csv")
files = files[files != "Mueller.csv"]
fit <- do.call(rbind,lapply(files, read.csv))
fit[, 2:5] = fit[, 2:5]*1000      


  O.match = do.call("rbind", replicate(length(unique(fit$type)), O, simplify = FALSE))
  error  =   rowSums( abs((O.match[ ,3:6] - fit[, 2:5])) , na.rm = T)
  O.match$error = error
  
  O.match = data.table(fit, O.match)
  O.match$error[O.match$error == Inf] = 10^10
  
  best = O.match[ , .I[error == min(error, na.rm = T)], by = Level]
  best = O.match[best$V1]
  
  best$type
  
  n = O$N*100
  
  
  h1 =   rgengamma.stacy( n[1], best$V5[1], best$V6[1],  best$V7[1])
  h2 =   rgengamma.stacy( n[2], best$V5[2], best$V6[2],  best$V7[2])
  h3 = rtruncnorm(n[3], a= 0, b = Inf, mean = best$V5[3], sd = best$V6[3])
  h4 = rllog(n[4], best$V5[4], best$V6[4])
  h5 = rllog(n[5], best$V5[5], best$V6[5])
  h6 = rburr(n[6],  shape1 = best$V5[6], shape2 = best$V6[6], scale =  best$V7[6])
  h7 = rburr(n[7],  shape1 = best$V5[7], shape2 = best$V6[7], scale =  best$V7[7])
  h8 = rllog(n[8], best$V5[8], best$V6[8])
  h9 = rllog(n[9], best$V5[9], best$V6[9])
  
  
  x = c(h1, h2, h3, h4, h5, h6, h7, h8, h9)
  g.mueller =  ineq(x)


setwd("/home/blair/Desktop/Empirical Research/Income Distribution/Global Gini")
g = read.csv("Gini.csv", stringsAsFactors = F) %>% na.omit() 
g.uk = read.csv("Gini.csv") %>% na.omit 
g.uk =  subset(g.uk, g.uk$Country.Name == "United Kingdom")

d = rbind(
  data.frame(g = g.mueller, type = "Mueller et al.", stringsAsFactors = F),
  data.frame(g = g.uk$Gini/100 , type = "United Kingdom", stringsAsFactors = F) 
)


setwd("/home/blair/Desktop/Empirical Research/Income Distribution/Gini Ratio/Hierarchical Levels/Empirical/Aggregate Studies/Mueller/Results")
write_csv(d, "Mueller Global Ineq.csv")

