library(pracma)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(here)

dir = here()
setwd(dir)


rep.row<-function(x,n){
  matrix(rep(x,each=n),nrow=n)
}
rep.col<-function(x,n){
  matrix(rep(x,each=n), ncol=n, byrow=TRUE)
}


# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")


d1 = read_csv("Dohmen_2.csv")
d1[d1 < 0] = 0
start = c(14.6,rep(0,8))
d1 = rbind(start, d1)
d1$Curve3[d1$x> 50] = 0


l = length(d1$x)

# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)


p =  foreach (i = 2:l, .options.snow=opts,  .combine=rbind, .packages=c('pracma') ) %dopar%  {


    x = d1$x[1:i]
    area = function(y){trapz(x,y)}
    d.sub = d1[1:i,-1]
    result = apply(d.sub, 2, area)

}


t_f =  foreach (i = 2:l, .options.snow=opts,  .combine=rbind, .packages=c('pracma') ) %dopar%  {
  
  
  x = d1$x[1:i]
  area = function(y){trapz(x,y)}
  d.sub = d1[1:i,-1]*x
  result = apply(d.sub, 2, area)
  
}


stopCluster(cl)
endTime <- proc.time()
time = endTime-startTime
close(pb)


mu = rep.row(t_f[524,], 524)
L = t_f/mu

norm = rep.row(p[524,], 524)
p.norm = p/norm
gini = 1:8

for(i in 1:8){
  gini[i] = (0.5- trapz(p.norm[,i], L[,i]))/0.5
}
  
output = data.frame(Level = 1:8, Gini = gini)
write_csv(output, "Dohmen Gini.csv")







