print("Gen Gamma")
# code from Andrie de Vries
# https://www.r-bloggers.com/parameters-and-percentiles-the-gamma-distribution/

#library(actuar)
library(ineq)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(data.table)
library(truncnorm)
library(VGAM)



# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")



O = read_csv("Grund Merge.csv")

error <- function(p=c(10, 3, 1), quantiles, exp){
  gx <- qgengamma.stacy(p=quantiles,  scale =p[1], d =p[2], k = p[3])
  sum(abs((gx-exp)))
}

quants <- c(0.05, 0.95)
l = length(O$x)



# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)

fit =  foreach (i = 1:l, .options.snow=opts,  .combine=rbind, .packages=c('ineq', 'VGAM', 'data.table')) %dopar%  {
  
  q = as.numeric(O[i , 4:5]/1000)
  solution <- nlm(f=error, p= c(1, 1, 10), quantiles = quants, exp=q)
  
  x = rgengamma.stacy(10^5, solution$estimate[1], solution$estimate[2], solution$estimate[3])

  gini = ineq(x)
  mean = mean(x)
  
  test = qgengamma.stacy(quants, solution$estimate[1], solution$estimate[2], solution$estimate[3])
  missing = 5 - length(test)
test = c(test, rep(NA, missing))
test = t(test)


  data.table(gini, mean, test, type = "Gen Gamma", solution$estimate[1], solution$estimate[2], solution$estimate[3], NA)
  
}
stopCluster(cl)
endTime = proc.time()
time = endTime - startTime


write_csv(fit, "Gen Gamma Results.csv")






  


