print("Lnorm")
# code from Andrie de Vries
# https://www.r-bloggers.com/parameters-and-percentiles-the-gamma-distribution/

library(NORMT3)
library(actuar)
library(ineq)
library(readr)
library(doSNOW)
library(foreach)
library(snow)
library(tcltk)
library(data.table)


# Clusters
##################################################
cl <- makeCluster(4, type="SOCK")
registerDoSNOW(cl)
clusterSetupRNG (cl, type = "RNGstream")



O = read_csv("Treble_mean.csv")


error <- function(p=c(1, 1), quantiles, exp){
  gx <- qlnorm(p=quantiles, meanlog = p[1], sdlog = p[2])
  sum(abs((gx-exp)))
}

quants <- c(0.05, 0.95)
l = length(O$x)



# Progress Bar
####################################
startTime <- proc.time()
pb <- txtProgressBar(max=l, style=3)
progress <- function(n) setTxtProgressBar(pb, n)
opts <- list(progress=progress)

fit =  foreach (i = 1:l, .options.snow=opts,  .combine=rbind, .packages=c('ineq',  'data.table', 'NORMT3')) %dopar%  {
  
  q = as.numeric(O[i , c(3,5)]/1000)
  solution <- nlm(f=error, p= c(0.5, 0.3), quantiles = quants, exp=q)
  

  gini = Re(erf(solution$estimate[2]/2))
  mean = exp(solution$estimate[1] +0.5*solution$estimate[2]^2)
  
  test = qlnorm(quants, solution$estimate[1], solution$estimate[2] )

  missing = 5 - length(test)
  test = c(test, rep(NA, missing))
  test = t(test)

  data.table(gini, mean, test, type =  "Lnorm", solution$estimate[1], solution$estimate[2], NA, NA)
  
}
stopCluster(cl)
endTime = proc.time()
time = endTime - startTime


write_csv(fit, "Lnorm Results.csv")





