library(data.table)
library(here)
library(magrittr)

dir = here()
setwd(dir)

military = fread("military_rank_pay.csv")

# remove unknown ranks
unknown = grep("Unknown", military$rank)
military = military[-unknown]

# remove warrant officers
warrant = grep("W", military$rank)
military = military[-warrant]

# ranks in two columns and order by increasing rank
military$rank_letter = gsub("[0-9]", "", military$rank)
military$rank_number = gsub("[^0-9]", "", military$rank) %>% as.numeric()
military = military[order(year, rank_letter, rank_number)]

military$rank_letter[military$rank_letter == "E"] = "Enlisted"
military$rank_letter[military$rank_letter == "O"] = "Officer"

# span of control
span_func = function(x){
  n = length(x)
  span = x[-n] / x[-1]
  return(span)
}
  
span = military[, span_func(number), by = year]
names(span) = c("year", "span")

# export
fwrite(span, "span_of_control.csv")
