library(magrittr)
library(data.table)
library(ggplot2)
library(gridExtra)
library(here)

dir = here()
text.size = 10


#-------------------------------------------------------
# beta vis

# empirical

  # cannons point
  setwd(dir)
  setwd("../data/solomon")
  slave = fread("solomon_power.csv")
  
  # us military
  setwd(dir)
  setwd("../data/military")
  military = fread("military_power.csv")
  
  # case studies
  setwd(dir)
  setwd("../data/firm_case_studies")
  case_study = fread("case_subordinates.csv")[,-1:-9]
  
  # ceos
  setwd(dir)
  setwd("../data/ceos")
  ceos = fread("ceo_pay.csv")
  ceos = data.table(power = ceos$Employees, pay_norm = ceos$ceo_pay_ratio)
  
  # merge
  all_data = rbind(military, case_study, ceos, slave)

# model
n = 7
power = rep(10^(0:6), n)
beta = rep(  seq(0.1, 1, length.out = n), each = 7)
income = power^beta
mod =  data.table(power, income, beta = as.character(beta))

# labels
bks = 10^(0:6)
lbs = prettyNum(bks, big.mark = ",", scientific = FALSE)

# text
power = rep(10^6, n)
beta =  seq(0.1, 1, length.out = n)
income = power^beta
legend =  data.table(power, income, beta = paste("D==", beta, sep = ""))


# plot
mod_plot = ggplot(data = mod) +
  geom_point(data = all_data, aes(x = power, y = pay_norm), size = 0.4, col = "grey") +
  geom_path(aes(x = power, y = income, col = beta)) +
  scale_x_log10("Hierarchical power", breaks = bks, labels = lbs) +
  scale_y_log10("Relative income", breaks = bks, labels = lbs) +
  scale_color_discrete("Hierarchical despotism index", guide = guide_legend(reverse = T)) +
  coord_cartesian(xlim = c(1, 10^6.7)) +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = "none",
        legend.key.height = unit(2, "cm"),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5),
        axis.line = element_line(color = "black"), 
        axis.title.x=element_text(vjust=-0.3, size=rel(0.9)),
        axis.title.y=element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times")) +
  geom_text(data = legend, aes(x = 2.5*power, y = income, label = beta), 
            parse = T, size = 2.5, family = "Times") +
  annotate("text", label = "Empirical\ndata", x = 10^4, y = 80, size = 2, family = "Times") +
  annotate("text", label = "Degree of\nhierarchical despotism", x = 10^6, y = 10^6.5, size = 2.8, family = "Times")
  
# export
setwd(dir)
gA = ggplotGrob(mod_plot)

png("beta_diagram.png", width = 5, height = 4.5, res = 600, units = "in")
grid.arrange(gA)
dev.off()
