library(data.table)
library(here)
library(stringr)
library(ggplot2)
library(grid)

text.size = 10
dir = here()
setwd(dir)

# cannons point
setwd(dir)
setwd("../data/solomon")
slave = fread("solomon_power.csv")

# us military
setwd(dir)
setwd("../data/military")
military = fread("military_power.csv")

# case studies
setwd(dir)
setwd("../data/firm_case_studies")
case_study = fread("case_subordinates.csv")[,-1:-9]

# ceos
setwd(dir)
setwd("../data/ceos")
ceos = fread("ceo_pay.csv")
ceos = data.table(power = ceos$Employees, pay_norm = ceos$ceo_pay_ratio)

# regression
all_data = rbind(military, case_study, ceos, slave)

  x = log(all_data$power)
  y = log(all_data$pay_norm)
  
  r = lm(y ~ x)
  r.square = summary(r)$r.squared
  x = seq(log(0.1), log(10^7), length.out = 50)
  x = data.frame(x)
  
  regression = exp(predict(r, x,  interval = "confidence", level = 0.99))
  regression = data.frame(x = exp(x), regression)
  r =  paste("R^2 ==~", round(r.square,2))

# labels
bks = 10^(0:5)
lbs = prettyNum(bks, big.mark = ",", scientific = FALSE)
  
# plot
despotism_plot = ggplot() +
  geom_ribbon(data = regression, aes( x = x, ymin = lwr, ymax = upr), fill = "black", alpha = 0.1) +
  geom_line(data = regression, aes(x = x, y = fit), col = "grey50") +
  geom_point(data = ceos, aes(x = power, y = pay_norm, col = "US CEOs"), size = 0.1) + 
  geom_point(data = case_study, aes(x = power, y = pay_norm, col = "Case-Study Firms"), size = 0.8) +
  geom_point(data = military, aes(x = power, y = pay_norm, col = "US Military"), size = 0.8) +
  geom_point(data = slave, aes(x = power, y = pay_norm, col = "Cannon's Point Slave Estate"), size = 0.8) +
  scale_x_log10("Hierarchical power", breaks = bks, labels = lbs) +
  scale_y_log10("Relative income", breaks = bks, labels = lbs) +
  guides(colour = guide_legend(override.aes = list(size = 1.5))) +
  coord_cartesian(xlim = c(0.8, 10^5.7), ylim = c(0.8, 10^4.2)) +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = c(0.2, 0.85),
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5),
        axis.line = element_line(color = "black"), 
        axis.title.x = element_text(vjust=-0.3, size=rel(0.9)),
        axis.title.y = element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times")) +
  annotate("text", x = 3, y = 15, label = r, parse = T, family="Times", size=3) 


# export
setwd(dir)
gA = ggplotGrob(despotism_plot)

png("despotism_index.png", width = 5, height = 4.6, res = 600, units = "in")
grid.draw(gA)
dev.off()



