library(data.table)
library(here)
library(ggplot2)
library(gridExtra)
library(magrittr)

text.size = 10
dir = here()
setwd(dir)

# data
setwd(dir)
setwd("../data/eia/form_860")
plant = fread("plant_capacity_by_type.csv")

mean(plant$capacity[plant$type == "Nuclear"]) /
mean(plant$capacity[plant$type == "Solar"])


# order by mean capacity
plant$type = as.factor(plant$type)
plant$type = reorder(plant$type, -plant$capacity, mean)

# breaks
bks = 10^(-1:5)
lbs = prettyNum(bks, big.mark = ",", scinote = F)

# plot
plant_plot = ggplot(data = plant) +
  geom_boxplot(aes(x = type, y = capacity, fill = class), outlier.color = NA) +
  scale_y_log10("Plant capacity (MW)", breaks = bks, labels = lbs) +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = c(0.85, 0.9),
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5),
        axis.line = element_line(color = "black"), 
        axis.title.x = element_blank(),
        axis.title.y = element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times"))
  

# export
setwd(dir)
gA = ggplotGrob(plant_plot)

png("plant_size_by_type.png", width = 5, height = 4.5, res = 600, units = "in")
grid.arrange(gA)
dev.off()

