library(hmod)
library(magrittr)
library(here)

dir = here()

scale_common = function(x){
  (x - min(x)) / (max(x) - min(x))
}  

n_mod = 500


# effect of hierarchy size
#------------------------------------------------
beta = 0.5
s = 3
firm_vec = 10^(seq(0, 5, length.out = n_mod)) %>% round() %>% unique()
g = rep(NA, length(firm_vec))

for(i in 1:length(firm_vec)){

  f = firm_vec[i]
  h = hierarchy(f, s)
  hp = hierarchical_power(h)
  
  pay = hp^beta
  dist = rep(pay, h)
  g[i] = gini(dist)
  
}


scaled = scale_common(firm_vec)
size_effect = data.table(firm_vec, scaled,  gini = g, type = "size")


# effect of span of control
#------------------------------------------------
beta = 0.5
firm_size = 10^5
span_vec = seq(2, 50, length.out = n_mod)
g = rep(NA, length(firm_size))

for(i in 1:length(span_vec)){
  
  s = span_vec[i]
  h = hierarchy(firm_size, s)
  hp = hierarchical_power(h)
  
  pay = hp^beta
  dist = rep(pay, h)
  g[i] = gini(dist)
  
}

scaled = scale_common(span_vec)
span_effect = data.table(span_vec, scaled, gini = g, type = "span")



# effect of beta
#------------------------------------------------
firm_size = 10^5
s = 3
beta_vec = seq(0.1, 1.1, length.out = n_mod)
g = rep(NA, length(firm_size))

for(i in 1:length(span_vec)){
  
  h = hierarchy(firm_size, s)
  hp = hierarchical_power(h)
  
  pay = hp^beta_vec[i]
  dist = rep(pay, h)
  g[i] = gini(dist)
  
}

scaled = scale_common(beta_vec)
beta_effect = data.table(beta_vec, scaled , gini =  g, type = "beta")



# merge data
#------------------------------------------------
all = rbind(
  size_effect[,-1],
  span_effect[, -1],
  beta_effect[, -1]
  )

# export
setwd(dir)
fwrite(all, "mod_results.csv")


