library(hmod)
library(here)
library(magrittr)
library(data.table)

dir = here()
setwd(dir)

#---------------------------------
# compustat all
setwd("/home/blair/Research/data/compustat_complete")
compustat = fread("compustat_complete_2018.csv")
comp_sic = data.table(Ticker = compustat$tic, SIC = compustat$sic) %>% unique()

#---------------------------------
# ceos
setwd(dir)
setwd("../../data/ceos")
ceo = fread("ceo_pay.csv")

# merge
ceo = merge(ceo, comp_sic, by = "Ticker")

# case studies
#---------------------------------
setwd(dir)
setwd("../../data/firm_case_studies")
case_study = fread("case_subordinates.csv")
span = mean(case_study$span, na.rm = T)

# get beta
#---------------------------------
beta_ceo = rep(NA, nrow(ceo))

for(i in 1:nrow(ceo)){
    
    firm_size = ceo$Employees[i]
    h = hierarchy(firm_size, span)
    hp = hierarchical_power(h)
    pay_ratio_empirical = ceo$ceo_pay_ratio[i]
    
    error = function(beta){
      
      pay = hp^beta
      mean_pay = weighted_mean(pay, h)
      pay_ratio = max(pay) / mean_pay
      error = abs(pay_ratio - pay_ratio_empirical)
      return(error)
    }
    
    solution <- nlminb(start = 0.5,  error, lower = 0.0001, upper = 5, control = list(iter.max = 100))
    beta_ceo[i] = solution$par  

}

result = data.table(ceo, beta = beta_ceo)
n = names(result) %>% tolower()
names(result) = n

# export
setwd(dir)
fwrite(result, "beta_kfrac.csv")

